@@ -1,14 +1,14 @@
 package WordList::ID::Animal::PERLANCAR;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-10-04'; # DATE
+our $DATE = '2021-02-02'; # DATE
 our $DIST = 'WordList-ID-Animal-PERLANCAR'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contains_nonword_chars",29,"num_words_contain_whitespace",17,"shortest_word_len",3,"num_words_contains_whitespace",17,"num_words_contain_nonword_chars",29,"avg_word_len",6.58962264150943,"num_words_contains_unicode",0,"longest_word_len",15,"num_words",212,"num_words_contain_unicode",0); # STATS
+our %STATS = ("num_words_contains_whitespace",17,"num_words_contains_unicode",0,"num_words_contain_whitespace",17,"num_words_contain_nonword_chars",29,"avg_word_len",6.58962264150943,"shortest_word_len",3,"longest_word_len",15,"num_words_contain_unicode",0,"num_words_contains_nonword_chars",29,"num_words",212); # STATS
 
 1;
 # ABSTRACT: List of animals in Indonesian
@@ -23,7 +23,7 @@ WordList::ID::Animal::PERLANCAR - List of animals in Indonesian
 
 =head1 VERSION
 
-This document describes version 0.002 of WordList::ID::Animal::PERLANCAR (from Perl distribution WordList-ID-Animal-PERLANCAR), released on 2020-10-04.
+This document describes version 0.003 of WordList::ID::Animal::PERLANCAR (from Perl distribution WordList-ID-Animal-PERLANCAR), released on 2021-02-02.
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ Source repository is at L<https://github.com/perlancar/perl-WordList-ID-Animal-P
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList-ID-Animal-PERLANCAR>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-WordList-ID-Animal-PERLANCAR/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -96,13 +96,15 @@ feature.
 
 =head1 SEE ALSO
 
+L<hangman> from L<Games::Hangman>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
